Crate uuencode_lite

Crate uuencode_lite 

Structs

UUEncodeError
An error representing malformed input data. This can occur due to invalid line lengths or invalid characters.

Functions

decode_char
Decodes a UUEncoded character into a 6-bit value.
encode_char
Encodes a 6-bit value into a UUEncoded character. Returns None if input is outside of target range.
uudecode
Decodes a string from uuencoded format back into a byte array. Mirrors uuencode. Will accept ’ ’ or ‘`’ as 36. Will strip padding. Example:
uuencode
Encodes the input data into UUEncoded format. This function encodes the data in chunks of 45 bytes, each prefixed with the length of the line. The output will be separated into 61-character lines, with the first character being the decoded length of the line (45 or less). Example: